@@ -20,9 +20,11 @@
 #include "itkImageSamplerBase.h"
 #include "itkGradientImageFilter.h"
 #include "itkBSplineInterpolateImageFunction.h"
+#include "itkReducedDimensionBSplineInterpolateImageFunction.h"
 #include "itkLimiterFunctionBase.h"
 #include "itkFixedArray.h"
 #include "itkAdvancedTransform.h"
+#include "vnl/vnl_sparse_matrix.h"
 
 namespace itk
 {
@@ -53,6 +55,12 @@ namespace itk
  * \li Some convenience functions are provided, such as the IsInsideMovingMask
  *   and CheckNumberOfSamples.
  *
+ * The parameters used in this class are:
+ * \parameter MovingImageDerivativeScales: scale the moving image derivatives. Use\n
+ *    <tt>(MovingImageDerivativeScales 1 1 0)</tt>\n
+ *    to penalize deformations in the z-direction. The default value is that
+ *    this feature is not used.
+ *
  * \ingroup RegistrationMetrics
  *
  */
@@ -142,7 +150,8 @@ public:
 
   /** Hessian type; for SelfHessian (experimental feature) */
   typedef typename DerivativeType::ValueType              HessianValueType;
-  typedef Array2D<HessianValueType>                       HessianType;
+  //typedef Array2D<HessianValueType>                       HessianType;
+  typedef vnl_sparse_matrix<HessianValueType>             HessianType;
 
   /** Public methods ********************/
 
@@ -251,6 +260,8 @@ protected:
     MovingImageType, CoordinateRepresentationType, double>      BSplineInterpolatorType;
   typedef BSplineInterpolateImageFunction<
     MovingImageType, CoordinateRepresentationType, float>       BSplineInterpolatorFloatType;
+  typedef ReducedDimensionBSplineInterpolateImageFunction<
+    MovingImageType, CoordinateRepresentationType, double>      ReducedBSplineInterpolatorType;
   typedef typename BSplineInterpolatorType::CovariantVectorType MovingImageDerivativeType;
   typedef GradientImageFilter<
     MovingImageType, RealType, RealType>                        CentralDifferenceGradientFilterType;
@@ -268,8 +279,10 @@ protected:
   /** Variables for image derivative computation. */
   bool m_InterpolatorIsBSpline;
   bool m_InterpolatorIsBSplineFloat;
+  bool m_InterpolatorIsReducedBSpline;
   typename BSplineInterpolatorType::Pointer             m_BSplineInterpolator;
-  typename BSplineInterpolatorFloatType::Pointer             m_BSplineInterpolatorFloat;
+  typename BSplineInterpolatorFloatType::Pointer        m_BSplineInterpolatorFloat;
+  typename ReducedBSplineInterpolatorType::Pointer      m_ReducedBSplineInterpolator;
   typename CentralDifferenceGradientFilterType::Pointer m_CentralDifferenceGradientFilter;
 
   /** Variables to store the AdvancedTransform. */
@@ -314,7 +327,7 @@ protected:
    * Checks if the point lies within the moving image buffer (bool return).
    * If no gradient is wanted, set the gradient argument to 0.
    * If a BSplineInterpolationFunction is used, this class obtain
-   * image derivatives from the BSpline interpolator. Otherwise,
+   * image derivatives from the B-spline interpolator. Otherwise,
    * image derivatives are computed using nearest neighbor interpolation
    * of a precomputed (central difference) gradient image. */
   virtual bool EvaluateMovingImageValueAndDerivative(
