@@ -43,6 +43,19 @@ namespace elastix
   * simplify usage. In most registration problems, good results should be obtained without specifying
   * any of the parameters described below (except the first of course, which defines the optimizer
   * to use).
+  *
+  * This optimization method is described in the following references:
+  *
+  * [1] P. Cruz,
+  * "Almost sure convergence and asymptotical normality of a generalization of Kesten's
+  * stochastic approximation algorithm for multidimensional case."
+  * Technical Report, 2005. http://hdl.handle.net/2052/74
+  *
+  * [2] S. Klein, J.P.W. Pluim, and M. Staring, M.A. Viergever,
+  * "Adaptive stochastic gradient descent optimisation for image registration,"
+  * International Journal of Computer Vision, vol. 81, no. 3, pp. 227-239, 2009.
+  * http://dx.doi.org/10.1007/s11263-008-0168-y
+
   *
   * The parameters used in this class are:
   * \parameter Optimizer: Select this optimizer as follows:\n
@@ -306,6 +319,8 @@ protected:
   /** RandomGenerator for AddRandomPerturbation. */
   typename RandomGeneratorType::Pointer             m_RandomGenerator;
 
+  double m_SigmoidScaleFactor;
+
   /** Check if the transform is an advanced transform. Called by Initialize. */
   virtual void CheckForAdvancedTransform( void );
 
